@@ -4,7 +4,7 @@
 #include <math.h> //sin
 #include <string.h>
 
-#include "../configure.h" //e.g. DATA_DIR
+#include "../../configure.h" //e.g. DATA_DIR
 #include "../jammo-track-view.h"
 #include "../jammo-cursor.h"
 #include "../jammo-mentor.h"
