@@ -4,9 +4,9 @@
 
 #define BUFFER_SIZE 6
 
-#define JAMMERIMGPATH "/opt/jammo/jammer"
+#define JAMMERIMGPATH DATA_DIR "/jammer"
 
-#define JAMMERSOUNDPATH "/opt/jammo/jammer/jammersounds"
+#define JAMMERSOUNDPATH DATA_DIR "/jammer/jammersounds"
 
 
 void start_jammer();
