@@ -108,6 +108,7 @@ void midieditor_zoom_clicked  (TangleButton *tanglebutton, gpointer user_data)
 		jammo_miditrack_view_set_show_grid(static_jammo_miditrack_view,FALSE);
 		jammo_miditrack_view_set_editing_enabled(static_jammo_miditrack_view,FALSE);
 		jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view,FALSE);
+		jammo_miditrack_view_set_eraser_mode(static_jammo_miditrack_view,FALSE);
 
 		jammo_chum_disable_actor(jammo_get_actor_by_id("button_pencil"));
 		jammo_chum_disable_actor(jammo_get_actor_by_id("button_eraser"));
@@ -161,7 +162,17 @@ void midieditor_playstop_clicked  (TangleButton *tanglebutton, gpointer user_dat
  * JSON callback
  */
 void midieditor_pencil_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
-	jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, (!jammo_miditrack_view_get_pen_mode(static_jammo_miditrack_view)));
+	if (jammo_miditrack_view_get_pen_mode(static_jammo_miditrack_view)) {
+		jammo_miditrack_view_set_editing_enabled(static_jammo_miditrack_view, TRUE);
+		jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, FALSE);
+		jammo_miditrack_view_set_eraser_mode(static_jammo_miditrack_view, FALSE);
+	}
+	else {
+		jammo_miditrack_view_set_editing_enabled(static_jammo_miditrack_view, FALSE);
+		jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, TRUE);
+		jammo_miditrack_view_set_eraser_mode(static_jammo_miditrack_view, FALSE);
+	}
+ tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("button_eraser")),FALSE);
 }
 
 /**
@@ -169,7 +180,17 @@ void midieditor_pencil_clicked  (TangleButton *tanglebutton, gpointer user_data)
  * JSON callback
  */
 void midieditor_eraser_clicked  (TangleButton *tanglebutton, gpointer user_data)  {
-	//jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, (!jammo_miditrack_view_get_pen_mode(static_jammo_miditrack_view)));
+	if (jammo_miditrack_view_get_eraser_mode(static_jammo_miditrack_view)) {
+		jammo_miditrack_view_set_editing_enabled(static_jammo_miditrack_view, TRUE);
+		jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, FALSE);
+		jammo_miditrack_view_set_eraser_mode(static_jammo_miditrack_view, FALSE);
+	}
+	else {
+		jammo_miditrack_view_set_editing_enabled(static_jammo_miditrack_view, FALSE);
+		jammo_miditrack_view_set_pen_mode(static_jammo_miditrack_view, FALSE);
+		jammo_miditrack_view_set_eraser_mode(static_jammo_miditrack_view, TRUE);
+	}
+ tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("button_pencil")),FALSE);
 }
 
 /**
