@@ -7,6 +7,7 @@
  * Authors: Henrik Hedberg <henrik.hedberg@oulu.fi>
  */
 
+#include "../configure.h"
 #include "jammo-chum.h"
 #include "../meam/jammo-meam.h"
 #include "jammo-mentor.h"
@@ -82,7 +83,9 @@ static TangleStylesheet* get_jammo_stylesheet(void) {
 	if (g_file_test(filename, G_FILE_TEST_EXISTS)) {
 		stylesheet = tangle_stylesheet_new_from_file(filename);
 	} else {
-		stylesheet = tangle_stylesheet_new_from_file("/opt/jammo/stylesheet");
+		gchar *filename2 = g_build_filename(DATA_DIR, "stylesheet", NULL);
+		stylesheet = tangle_stylesheet_new_from_file(filename2);
+		g_free(filename2);
 	}
 
 	g_free(cwd);
@@ -96,7 +99,7 @@ static TangleStylesheet* get_jammo_stylesheet(void) {
  * 	<current_working_directory>/data/jammo
  */
 static void add_search_paths(ClutterScript* script) {
-	const gchar* default_search_path = "/opt/jammo";
+	const gchar* default_search_path = DATA_DIR;
 	gchar* development_search_path3_6;
 	gchar* development_search_path7_12;
 	gchar* cwd;
