@@ -2,14 +2,14 @@
 #ifndef CONFIG_H_
 #define CONFIG_H_
 
-#include "../configure.h"
+#include "../../configure.h"
 //SETS FULLSCREEN on/off  ...Must be TRUE for 800x480 resolutions
 #define SET_FULLSCREEN FALSE
 
 //USE JAMMOS CONFIGURATION.H
 #define PATH_DEVICE TRUE
 
-#define PG_IMAGES_DIR "/opt/jammo/password";
+#define PG_IMAGES_DIR DATA_DIR "/password";
 #define INKML_FILE_PATH JAMMO_DIRECTORY "/motion_inkml.xml";
 #define PG_VERSION "v.0.4.1";
 
