@@ -3,7 +3,7 @@
 #define READ_USER_PASS_FROM_FILE_H_
 
 
-int get_user_passwd();
+int *get_user_passwd();
 
 #endif /* READ_USER_PASS_FROM_FILE_H_ */
 
