@@ -16,6 +16,8 @@ License:LGPL 2.1
 #include "../plugin-common.h"
 #include "gstjammoslider.h"
 
+#include "../../../configure.h" // for DATA_DIR
+
 /*e.g. Nokia Internet Tablet n810 doesn't have this (maemo diablo)*/
 #ifndef G_PARAM_STATIC_STRINGS
 #define	G_PARAM_STATIC_STRINGS (G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB)
@@ -47,11 +49,6 @@ License:LGPL 2.1
 // volume of blow sound with FM_MODULATION algorithm
 #define BLOW_VOLUME 0.25
 
-/*	This is temporary hack:
-*/
-#define DATA_DIR "/opt/jammo"
-/* Actually, DATA_DIR should be defined using configure script... */
-
 #define SLIDER_FOLDER DATA_DIR "/virtual-instruments/slider/"
 
 static const GstElementDetails gst_jammo_slider_details =
