@@ -23,7 +23,7 @@ void _jammo_sample_set_editing_track(JammoSample* sample, JammoEditingTrack* edi
 GstElement* _jammo_sample_get_element(JammoSample* sample);
 
 /* jammo-track.c */
-gboolean _jammo_track_setup_element(JammoTrack* track, GstBin* bin, GstElement* sink_element);
+gboolean _jammo_track_setup_element(JammoTrack* track, GstPipeline* pipeline, GstBin* bin, GstElement* sink_element);
 gboolean _jammo_track_receive_message(JammoTrack* track, GstMessage* message);
 void _jammo_track_set_tempo(JammoTrack* track, guint tempo);
 void _jammo_track_set_pitch(JammoTrack* track, const gchar* pitch);
